==> libgoose-0.0.2.tar.gz: libgoose-0.0.2/src/DataType.h <==
// This is -*- C++ -*-

/* 
 * DataType.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_DATATYPE_H
#define _INC_DATATYPE_H

#include <string>
#include <math.h>
#include <cstring>
#include <cstdio>

// Abstract interface used in DataSet

class DataType {
public:
  DataType() {} 
  virtual ~DataType() {}
  
  // Make the raw double into a string for display
  virtual string format  (double raw) const = 0;
  
  // Determine if the given string looks like it could
  //  be parsed by this type
  virtual bool   identify(const string & text) const = 0;

  // Should be able to parse anything we identified above
  // Return false if it can't parse for some reason; some parsers
  //  will have more safety checks than others.
  virtual bool   parse   (const string & text, double & d) const = 0;

  // name of the type for display to user
  // Has to go in Guppi; needs i18n.
  //  virtual string name () const = 0;
};

// Useful types; library users will probably want to instantiate
//  one of each and organize them somehow in a data structure,
//  and possibly subclass to handle i18n issues (date formatting), etc.

class RealType {
public:
  RealType() {}
  virtual ~RealType() {}

  string format (double raw) const { 
    char buf[100]; 
    // glib would help here. This isn't portable 
    //  but g_snprintf is. fixme
    snprintf(buf,100,"%f",raw);
    return buf;
  }

  bool identify (const string & text) const;

  bool parse (const string & text, double & d) const { d = atof(text.c_str()); return true; }
};

#endif // _INC_DATATYPE_H

==> libgoose-0.0.4.tar.gz: libgoose-0.0.4/src/DataType.h <==
// This is -*- C++ -*-

/* 
 * DataType.h
 *
 * Copyright (C) 1998 EMC Capital Management, Inc.
 *
 * Developed by Havoc Pennington <hp@pobox.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef _INC_DATATYPE_H
#define _INC_DATATYPE_H

#include <string>
#include <math.h>
#include <cstring>
#include <cstdio>

// Abstract interface used in DataSet

class DataType {
public:
  DataType() {} 
  virtual ~DataType() {}
  
  // Make the raw double into a string for display
  virtual string format  (double raw) const = 0;
  
  // Determine if the given string looks like it could
  //  be parsed by this type
  virtual bool   identify(const string & text) const = 0;

  // Should be able to parse anything we identified above
  // Return false if it can't parse for some reason; some parsers
  //  will have more safety checks than others.
  virtual bool   parse   (const string & text, double & d) const = 0;

  // name of the type for display to user
  // Needs i18n, so the types defined in Goose
  //  are not implementable. You have to subclass, implementing
  //  this function.
  virtual string name () const = 0;
};

// Useful types; library users will probably want to instantiate
//  one of each and organize them somehow in a data structure,
//  and possibly subclass to handle i18n issues (date formatting), etc.

class RealType : public DataType {
public:
  RealType() {}
  virtual ~RealType() {}

  string format (double raw) const { 
    char buf[100]; 
    // glib would help here. This isn't portable 
    //  but g_snprintf is. fixme
    snprintf(buf,100,"%f",raw);
    return buf;
  }

  bool identify (const string & text) const;

  bool parse (const string & text, double & d) const { d = atof(text.c_str()); return true; }
};

#endif // _INC_DATATYPE_H
